mp4

package
v0.0.0-...-dec19c8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	SegmentSuffixInit = "init.mp4"
	SegmentSuffix     = ".m4s"
	MPDSuffix         = "manifest.mpd"
)

Variables

This section is empty.

Functions

func Dump

func Dump(w io.Writer, path string, segDuration time.Duration)

Dump prints out codec info and segmentation patter for mp4 file.

func SegmentName

func SegmentName(track *mp4ff.TrakBox) string

Types

This section is empty.

Directories

Path Synopsis
Package meta contains playback metadata definition and static MPD generator.
Package meta contains playback metadata definition and static MPD generator.
Package segmentation contains high level functions for progressive mp4 file segmentation The code is mostly based on https://github.com/Eyevinn/mp4ff/tree/master/examples/segmenter
Package segmentation contains high level functions for progressive mp4 file segmentation The code is mostly based on https://github.com/Eyevinn/mp4ff/tree/master/examples/segmenter

Jump to